@@ -23,13 +23,8 @@ from enum import Enum
 import aws_encryption_sdk
 import six
 
-from aws_encryption_sdk_cli.exceptions import BadUserArgumentError, ParameterParseError
-from aws_encryption_sdk_cli.internal.identifiers import (
-    ALGORITHM_NAMES,
-    DEFAULT_MASTER_KEY_PROVIDER,
-    DEFAULT_WRAPPING_KEY_PROVIDER,
-    __version__,
-)
+from aws_encryption_sdk_cli.exceptions import ParameterParseError
+from aws_encryption_sdk_cli.internal.identifiers import ALGORITHM_NAMES, DEFAULT_MASTER_KEY_PROVIDER, __version__
 from aws_encryption_sdk_cli.internal.logging_utils import LOGGER_NAME
 from aws_encryption_sdk_cli.internal.metadata import MetadataWriter
 
@@ -43,35 +38,15 @@ try:  # Python 3.5.0 and 3.5.1 have incompatible typing modules
         MASTER_KEY_PROVIDER_CONFIG,
         PARSED_CONFIG,
         RAW_CONFIG,
-        WRAPPING_KEY_PROVIDER_CONFIG,
     )
 except ImportError:  # pragma: no cover
     cast = lambda typ, val: val  # noqa pylint: disable=invalid-name
     # We only actually need the other imports when running the mypy checks
 
-__all__ = (
-    "parse_args",
-    "CommitmentPolicyArgs",
-    "_process_wrapping_key_provider_configs",
-)
+__all__ = ("parse_args",)
 _LOGGER = logging.getLogger(LOGGER_NAME)
 
 
-def _is_decrypt_mode(mode):
-    # type: (str) -> bool
-    """
-    Determines whether the provided mode does decryption
-
-    :param str filepath: Full file path to file in question
-    :rtype: bool
-    """
-    if mode in ("decrypt", "decrypt-unsigned"):
-        return True
-    if mode == "encrypt":
-        return False
-    raise BadUserArgumentError("Mode {mode} has not been implemented".format(mode=mode))
-
-
 class CommentIgnoringArgumentParser(argparse.ArgumentParser):
     """``ArgumentParser`` that ignores lines in ``fromfile_prefix_chars`` files which start with ``#``."""
 
@@ -217,14 +192,6 @@ def _build_parser():
         "-d", "--decrypt", dest="action", action="store_const", const="decrypt", help="Decrypt data"
     )
     parser.add_dummy_redirect_argument("--decrypt")
-    operating_action.add_argument(
-        "--decrypt-unsigned",
-        dest="action",
-        action="store_const",
-        const="decrypt-unsigned",
-        help="Decrypt data and enforce messages are unsigned during decryption.",
-    )
-    parser.add_dummy_redirect_argument("--decrypt-unsigned")
 
     # For each argument added to this group, a dummy redirect argument must
     # be added to the parent parser for each long form option string.
@@ -251,22 +218,6 @@ def _build_parser():
         help="Force metadata output to overwrite contents of file rather than appending to file",
     )
 
-    parser.add_argument(
-        "-m",
-        "--master-keys",
-        nargs="+",
-        action="append",
-        required=False,
-        help=(
-            "Identifying information for a master key provider and master keys. Each instance must include "
-            "a master key provider identifier and identifiers for one or more master key supplied by that provider. "
-            "ex: "
-            "--master-keys provider=aws-kms key=$AWS_KMS_KEY_ARN "
-            "The --master-keys argument has been deprecated and will be removed in version 2.0. "
-            "Please use the --wrapping-keys argument instead."
-        ),
-    )
-
     parser.add_argument(
         "-w",
         "--wrapping-keys",
@@ -277,16 +228,16 @@ def _build_parser():
         help=(
             "Identifying information for a wrapping key provider and wrapping keys. Each instance must include "
             "a wrapping key provider identifier and identifiers for one or more wrapping key supplied by that "
-            "provider. ex: "
+            " provider. ex: "
             "--wrapping-keys provider=aws-kms key=$AWS_KMS_KEY_ARN"
         ),
     )
 
     parser.add_argument(
         "--commitment-policy",
-        dest="commitment_policy",
         type=CommitmentPolicyArgs,
         choices=list(CommitmentPolicyArgs),
+        default=CommitmentPolicyArgs.require_encrypt_require_decrypt,
         help=(
             "Specifies the commitment policy for key commitment. "
             "ex: "
@@ -307,10 +258,6 @@ def _build_parser():
         ),
     )
 
-    parser.add_argument(
-        "-b", "--buffer", action="store_true", help="Buffer result in memory before releasing to output"
-    )
-
     parser.add_argument(
         "-i",
         "--input",
@@ -350,6 +297,33 @@ def _build_parser():
         "--algorithm", action=UniqueStoreAction, help="Algorithm name (encryption only)", choices=ALGORITHM_NAMES
     )
 
+    parser.add_argument(
+        "--discovery",
+        type=discovery_pseudobool,
+        dest="discovery",
+        required=False,
+        help="Enable or disable discovery mode (decryption only)",
+    )
+
+    parser.add_argument(
+        "--discovery-account",
+        nargs="+",
+        dest="discovery_account",
+        action="append",
+        required=False,
+        help="AWS Account IDs used for key discovery (only with --discovery=true)",
+    )
+
+    parser.add_argument(
+        "--discovery-partition",
+        dest="discovery_partition",
+        action=UniqueStoreAction,
+        required=False,
+        help=(
+            "AWS Partition used for key discovery (only with --discovery=true)" "ex: " "--discovery-partition=aws-gov"
+        ),
+    )
+
     parser.add_argument(
         "--frame-length",
         dest="frame_length",
@@ -368,13 +342,6 @@ def _build_parser():
         ),
     )
 
-    parser.add_argument(
-        "--max-encrypted-data-keys",
-        type=int,
-        action=UniqueStoreAction,
-        help="Maximum number of encrypted data keys to wrap (during encryption) or to unwrap (during decryption)",
-    )
-
     parser.add_argument(
         "--suffix",
         nargs="?",
@@ -513,187 +480,98 @@ def _process_caching_config(raw_caching_config):
     return caching_config
 
 
-def _process_master_key_provider_configs(
-    raw_keys,  # type: List[RAW_CONFIG]
-    action,  # type: str
-):
-    # type: (...) -> List[MASTER_KEY_PROVIDER_CONFIG]
-    """Applied additional processing to prepare the master key provider configuration.
-
-    :param list raw_keys: List of master key provider configurations
-    :param str action: Action defined in CLI input
-    :param bool discovery: Are we in discovery mode?
-    :param Dict[str, Union[str, List[str]]] discovery_filter: Filter options for discovery mode
-    :returns: List of processed master key provider configurations
-    :rtype: list of dicts
-    :raises ParameterParseError: if exactly one provider value is not provided
-    :raises ParameterParseError: if no key values are provided
-    """
-    if raw_keys is None:
-        if _is_decrypt_mode(action):
-            # We allow not defining any master key provider configuration if decrypting with aws-kms.
-            _LOGGER.debug(
-                "No master key provider config provided on decrypt request. Using aws-kms with no master keys."
-            )
-            return [{"provider": DEFAULT_MASTER_KEY_PROVIDER, "key": [], "discovery": True}]
-        raise ParameterParseError("No master key provider configuration found")
-
-    _LOGGER.warning(
-        "The --master-keys argument has been deprecated and will be removed in version 2.0. "
-        "Please use the --wrapping-keys argument instead."
-    )
-
-    processed_configs = []  # type: List[MASTER_KEY_PROVIDER_CONFIG]
-    for raw_config in raw_keys:
-        parsed_args = {}  # type: Dict[str, Union[str, List[str], Dict[str, Union[str, List[str]]]]]
-        parsed_args.update(_parse_kwargs(raw_config))
-
-        # The --master-keys parameter does not support discovery attributes, but we need to set them so that
-        # later on we create the correct providers
-        if action == "encrypt":
-            parsed_args["discovery"] = False  # type: ignore
-        else:
-            parsed_args["discovery"] = True  # type: ignore
-
-        provider = parsed_args.get("provider", [DEFAULT_MASTER_KEY_PROVIDER])  # If no provider is defined, use aws-kms
-        if len(provider) != 1:
-            raise ParameterParseError(
-                'Exactly one "provider" must be provided for each master key provider configuration. '
-                "{} provided".format(len(provider))
-            )
-        parsed_args["provider"] = provider[0]  # type: ignore
-
-        aws_kms_on_decrypt = parsed_args["provider"] in ("aws-kms", DEFAULT_MASTER_KEY_PROVIDER) and _is_decrypt_mode(
-            action
-        )
-
-        if aws_kms_on_decrypt:
-            if "key" in parsed_args:
-                raise ParameterParseError(
-                    "With the --master-keys parameter, the user cannot specify master keys for aws-kms master key "
-                    "provider on decrypt"
-                )
-            parsed_args["key"] = []
-        elif "key" not in parsed_args:
-            raise ParameterParseError('At least one "key" must be provided for each master key provider configuration')
-        processed_configs.append(parsed_args)  # type: ignore
-    return processed_configs
-
-
 def _process_wrapping_key_provider_configs(  # noqa: C901
     raw_keys,  # type: List[RAW_CONFIG]
     action,  # type: str
+    discovery=None,  # type: bool
+    discovery_filter=None,  # type: Dict[str, Union[str, List[str]]]
 ):
-    # type: (...) -> List[WRAPPING_KEY_PROVIDER_CONFIG]
+    # type: (...) -> List[MASTER_KEY_PROVIDER_CONFIG]
     """Applied additional processing to prepare the wrapping key provider configuration.
 
     :param list raw_keys: List of wrapping key provider configurations
     :param str action: Action defined in CLI input
+    :param bool discovery: Are we in discovery mode?
+    :param Dict[str, Union[str, List[str]]] discovery_filter: Filter options for discovery mode
     :returns: List of processed wrapping key provider configurations
     :rtype: list of dicts
     :raises ParameterParseError: if exactly one provider value is not provided
     :raises ParameterParseError: if no key values are provided
     """
     if raw_keys is None:
-        if _is_decrypt_mode(action):
+        if action == "decrypt":
             # We allow not defining any wrapping key provider configuration if decrypting with aws-kms.
             _LOGGER.debug(
                 "No wrapping key provider config provided on decrypt request. Using aws-kms with no wrapping keys."
             )
-            return [{"provider": DEFAULT_MASTER_KEY_PROVIDER, "key": [], "discovery": True}]
-        raise ParameterParseError("No wrapping key provider configuration found")
+            return [{"provider": DEFAULT_MASTER_KEY_PROVIDER, "key": []}]
+        raise ParameterParseError("No wrapping key provider configuration found.")
 
-    processed_configs = []  # type: List[WRAPPING_KEY_PROVIDER_CONFIG]
+    if action == "decrypt" and discovery is None:
+        discovery = False
+
+    processed_configs = []  # type: List[MASTER_KEY_PROVIDER_CONFIG]
     for raw_config in raw_keys:
         parsed_args = {}  # type: Dict[str, Union[str, List[str], Dict[str, Union[str, List[str]]]]]
         parsed_args.update(_parse_kwargs(raw_config))
 
-        provider = parsed_args.get("provider", [DEFAULT_WRAPPING_KEY_PROVIDER])
+        provider = parsed_args.get("provider", [DEFAULT_MASTER_KEY_PROVIDER])  # If no provider is defined, use aws-kms
         if len(provider) != 1:
             raise ParameterParseError(
                 'Exactly one "provider" must be provided for each wrapping key provider configuration. '
                 "{} provided".format(len(provider))
             )
         parsed_args["provider"] = provider[0]  # type: ignore
-        provider_is_kms = parsed_args["provider"] in ("aws-kms", DEFAULT_WRAPPING_KEY_PROVIDER)
-        args_include_discovery = (
-            "discovery" in parsed_args or "discovery-account" in parsed_args or "discovery-partition" in parsed_args
-        )
-        if not provider_is_kms and args_include_discovery:
-            raise ParameterParseError("Discovery attributes are supported only for AWS KMS wrapping keys")
 
-        if action == "encrypt" and args_include_discovery:
-            raise ParameterParseError("Discovery attributes are supported only during decryption")
+        aws_kms_on_decrypt = parsed_args["provider"] in ("aws-kms", DEFAULT_MASTER_KEY_PROVIDER) and action == "decrypt"
 
-        _process_discovery_args(parsed_args)
-
-        discovery = parsed_args["discovery"]
-        if provider_is_kms and _is_decrypt_mode(action):
+        if aws_kms_on_decrypt:
             if "key" in parsed_args and discovery:
                 # Decrypt MUST fail without attempting any decryption if discovery mode is enabled
                 # and at least one key=<Key ARN> parameter value is provided
-                raise ParameterParseError("If discovery is true (enabled), you cannot specify wrapping keys")
-            if "key" not in parsed_args:
-                if not discovery:
-                    # Decrypt MUST fail without attempting any decryption if discovery mode is disabled
-                    # and no key=<Key ARN> parameter value is provided
-                    raise ParameterParseError(
-                        "When discovery is false (disabled), you must specify at least one wrapping key"
-                    )
-                parsed_args["key"] = []
-
-        if "key" not in parsed_args and action == "encrypt":
+                raise ParameterParseError(
+                    "Exact wrapping keys cannot be specified for aws-kms wrapping key provider on decrypt "
+                    "in discovery mode."
+                )
+            if "key" not in parsed_args and not discovery:
+                # Decrypt MUST fail without attempting any decryption if discovery mode is disabled
+                # and no key=<Key ARN> parameter value is provided
+                raise ParameterParseError(
+                    "At least one key must be specified for aws-kms wrapping key provider on decrypt "
+                    "when discovery mode is disabled."
+                )
+            parsed_args["key"] = []
+        elif "key" not in parsed_args:
             raise ParameterParseError(
-                "You must specify at least one key attribute and value in each --wrapping-keys parameter"
+                'At least one "key" must be provided for each wrapping key provider configuration'
             )
+        if discovery and discovery_filter:
+            parsed_args["discovery_filter"] = discovery_filter
         processed_configs.append(parsed_args)  # type: ignore
     return processed_configs
 
 
-def _process_discovery_args(key_config):  # noqa: C901
-    """Process rules for discovery filters on Account ID and Partition ID
-
-    :param key_config: The key configuration being parsed
-    :param action: The action being taken (encrypt or decrypt)
+def _process_discovery_args(parsed_args):
+    """
+    Process rules for discovery filters on Account ID and Partition ID
+    :param parsed_args:
+    :return: Dict[str, Union[str, List[str]]]
     :raises: ParameterParseError
     """
-    if "discovery" not in key_config:
-        if "discovery-account" in key_config or "discovery-partition" in key_config:
-            raise ParameterParseError(
-                "Discovery-account and discovery-partition are valid only when the discovery attribute is set to true"
-            )
+    if parsed_args.discovery is False:
+        if parsed_args.discovery_account:
+            raise ParameterParseError("Error: --discovery-account is only available if discovery is enabled")
+        if parsed_args.discovery_partition:
+            raise ParameterParseError("Error: --discovery-partition is only available if discovery is enabled")
+        return None
+    if not parsed_args.discovery_partition and not parsed_args.discovery_account:
+        return None
+    if parsed_args.discovery_partition and not parsed_args.discovery_account:
+        raise ParameterParseError("Error: --discovery-partition requires at least one --discovery-account")
+    if parsed_args.discovery_account and not parsed_args.discovery_partition:
+        raise ParameterParseError("Error: --discovery-account requires at least one --discovery-partition")
 
-        key_config["discovery"] = False
-        return
-
-    # Translate the raw value of 'discovery' as passed by customer into a bool we can work with
-    discovery = discovery_pseudobool(key_config.pop("discovery")[0])
-    key_config["discovery"] = discovery
-
-    accounts = key_config.get("discovery-account", None)
-    partition = key_config.get("discovery-partition", None)
-
-    if not discovery:
-        if accounts or partition:
-            raise ParameterParseError(
-                "Discovery-account and discovery-partition are valid only when the discovery attribute is set to true"
-            )
-    else:
-        if accounts and not partition:
-            raise ParameterParseError("When specifying discovery-account, you must also specify discovery-partition")
-        if partition and not accounts:
-            raise ParameterParseError("When specifying discovery-partition, you must also specify discovery-account")
-
-        if accounts and partition:
-            for account in accounts:
-                if len(account) == 0:
-                    raise ParameterParseError("Value passed to discovery-account cannot be empty")
-            if len(partition) != 1:
-                raise ParameterParseError("You can only specify discovery-partition once")
-            if not partition[0]:
-                raise ParameterParseError("Value passed to discovery-partition cannot be empty")
-
-            key_config["discovery-partition"] = partition[0]
+    return {"account_ids": parsed_args.discovery_account, "partition": parsed_args.discovery_partition}
 
 
 def discovery_pseudobool(value):
@@ -705,22 +583,22 @@ def discovery_pseudobool(value):
             return False
         if value.lower() in {"true", "t", "1", "yes", "y"}:
             return True
-    raise ParameterParseError("Value {} could not be parsed as true or false".format(value))
+    return None
 
 
 class CommitmentPolicyArgs(Enum):
     """Defines the possible values for a commitment policy"""
 
-    FORBID_ENCRYPT_ALLOW_DECRYPT = "forbid-encrypt-allow-decrypt"
-    # REQUIRE_ENCRYPT_ALLOW_DECRYPT = 'require-encrypt-allow-decrypt'
-    # REQUIRE_ENCRYPT_REQUIRE_DECRYPT = 'require-encrypt-require-decrypt'
+    forbid_encrypt_allow_decrypt = "forbid-encrypt-allow-decrypt"
+    require_encrypt_allow_decrypt = "require-encrypt-allow-decrypt"
+    require_encrypt_require_decrypt = "require-encrypt-require-decrypt"
 
     def str(self):
         """Returns the string value for the commitment policy"""
         return self.value
 
 
-def parse_args(raw_args=None):  # noqa
+def parse_args(raw_args=None):
     # type: (Optional[List[str]]) -> argparse.Namespace
     """Handles argparse to collect the needed input values.
 
@@ -737,33 +615,19 @@ def parse_args(raw_args=None):  # noqa
                 'Found invalid argument "{actual}". Did you mean "-{actual}"?'.format(actual=parsed_args.dummy_redirect)
             )
 
-        # We add the 'required_encryption_context_keys' to arg parse, even though it is not
-        # meant to be used by customers, so that we can  pass the parsed arguments around internally
+        if parsed_args.action == "decrypt" and parsed_args.discovery is None:
+            raise ParameterParseError("Discovery must be set to True or False.")
+        discovery_filter = _process_discovery_args(parsed_args)
+
         if parsed_args.required_encryption_context_keys is not None:
-            raise ParameterParseError("--required-encryption-context-keys cannot be manually provided")
+            raise ParameterParseError("--required-encryption-context-keys cannot be manually provided.")
 
         if parsed_args.overwrite_metadata:
             parsed_args.metadata_output.force_overwrite()
 
-        if parsed_args.master_keys and parsed_args.wrapping_keys:
-            raise ParameterParseError("You cannot specify both the --master-keys and --wrapping-keys parameters")
-        if parsed_args.wrapping_keys:
-            if not parsed_args.commitment_policy:
-                raise ParameterParseError("Commitment policy is required when specifying the --wrapping-keys parameter")
-
-            parsed_args.wrapping_keys = _process_wrapping_key_provider_configs(
-                parsed_args.wrapping_keys, parsed_args.action
-            )
-        else:
-            if parsed_args.commitment_policy:
-                raise ParameterParseError(
-                    "Commitment policy is only supported when using the --wrapping-keys parameter"
-                )
-
-            _LOGGER.warning(
-                "Beginning in version 2.1, the --wrapping-keys parameter is required in encrypt and decrypt commands"
-            )
-            parsed_args.master_keys = _process_master_key_provider_configs(parsed_args.master_keys, parsed_args.action)
+        parsed_args.wrapping_keys = _process_wrapping_key_provider_configs(
+            parsed_args.wrapping_keys, parsed_args.action, parsed_args.discovery, discovery_filter
+        )
 
         # mypy does not appear to understand nargs="+" behavior
         parsed_args.encryption_context, parsed_args.required_encryption_context_keys = _process_encryption_context(
