@@ -17,6 +17,7 @@ import shlex
 
 import aws_encryption_sdk
 import pytest
+from aws_encryption_sdk.materials_managers import CommitmentPolicy
 from mock import MagicMock, sentinel
 from pytest_mock import mocker  # noqa pylint: disable=unused-import
 
@@ -33,32 +34,32 @@ def patch_platform_win32_ver(mocker):
     return arg_parsing.platform.win32_ver
 
 
-@pytest.fixture
+@pytest.yield_fixture
 def patch_build_parser(mocker):
     mocker.patch.object(arg_parsing, "_build_parser")
     yield arg_parsing._build_parser
 
 
-@pytest.fixture
+@pytest.yield_fixture
 def patch_process_wrapping_key_provider_configs(mocker):
     mocker.patch.object(arg_parsing, "_process_wrapping_key_provider_configs")
     yield arg_parsing._process_wrapping_key_provider_configs
 
 
-@pytest.fixture
+@pytest.yield_fixture
 def patch_parse_and_collapse_config(mocker):
     mocker.patch.object(arg_parsing, "_parse_and_collapse_config")
     yield arg_parsing._parse_and_collapse_config
 
 
-@pytest.fixture
+@pytest.yield_fixture
 def patch_process_encryption_context(mocker):
     mocker.patch.object(arg_parsing, "_process_encryption_context")
     arg_parsing._process_encryption_context.return_value = sentinel.encryption_context, sentinel.required_keys
     yield arg_parsing._process_encryption_context
 
 
-@pytest.fixture
+@pytest.yield_fixture
 def patch_process_caching_config(mocker):
     mocker.patch.object(arg_parsing, "_process_caching_config")
     yield arg_parsing._process_caching_config
@@ -196,7 +197,7 @@ def test_unique_store_action_second_call():
     mock_parser.error.assert_called_once_with("SPECIAL_ATTRIBUTE argument may not be specified more than once")
 
 
-def build_expected_good_args(from_file=False):  # pylint: disable=too-many-locals,too-many-statements
+def build_expected_good_args(from_file=False):  # pylint: disable=too-many-locals
     encrypt = "-e"
     decrypt = "-d"
     suppress_metadata = " -S"
@@ -205,19 +206,20 @@ def build_expected_good_args(from_file=False):  # pylint: disable=too-many-local
     short_output = " -o -"
     long_output = " --output -"
     valid_io = short_input + short_output
-    mkp_1 = " --commitment-policy forbid-encrypt-allow-decrypt -w provider=ex_provider_1 key=ex_mk_id_1"
-    mkp_1_parsed = {"provider": "ex_provider_1", "key": ["ex_mk_id_1"], "discovery": False}
-    mkp_2 = " --commitment-policy forbid-encrypt-allow-decrypt -w provider=ex_provider_2 key=ex_mk_id_2"
-    mkp_2_parsed = {"provider": "ex_provider_2", "key": ["ex_mk_id_2"], "discovery": False}
+    mkp_1 = " -w provider=ex_provider_1 key=ex_mk_id_1"
+    mkp_1_parsed = {"provider": "ex_provider_1", "key": ["ex_mk_id_1"]}
+    mkp_2 = " -w provider=ex_provider_2 key=ex_mk_id_2"
+    mkp_2_parsed = {"provider": "ex_provider_2", "key": ["ex_mk_id_2"]}
     default_encrypt = encrypt + suppress_metadata + valid_io + mkp_1
+    default_discovery = " --discovery=true"
+    default_decrypt = decrypt + suppress_metadata + valid_io + mkp_1 + default_discovery
     good_args = []
 
     # encrypt/decrypt
     for encrypt_flag in (encrypt, "--encrypt"):
         good_args.append((encrypt_flag + suppress_metadata + valid_io + mkp_1, "action", "encrypt"))
     for decrypt_flag in (decrypt, "--decrypt"):
-        good_args.append((decrypt_flag + suppress_metadata + valid_io + mkp_1, "action", "decrypt"))
-    good_args.append(("--decrypt-unsigned" + suppress_metadata + valid_io + mkp_1, "action", "decrypt-unsigned"))
+        good_args.append((decrypt_flag + suppress_metadata + valid_io + mkp_1 + default_discovery, "action", "decrypt"))
 
     # wrapping key config
     good_args.append((default_encrypt, "wrapping_keys", [mkp_1_parsed]))
@@ -264,10 +266,6 @@ def build_expected_good_args(from_file=False):  # pylint: disable=too-many-local
     good_args.append((default_encrypt, "max_length", None))
     good_args.append((default_encrypt + " --max-length 99", "max_length", 99))
 
-    # max encrypted data keys
-    good_args.append((default_encrypt, "max_encrypted_data_keys", None))
-    good_args.append((default_encrypt + " --max-encrypted-data-keys 99", "max_encrypted_data_keys", 99))
-
     # interactive
     good_args.append((default_encrypt, "interactive", False))
     good_args.append((default_encrypt + " --interactive", "interactive", True))
@@ -300,10 +298,17 @@ def build_expected_good_args(from_file=False):  # pylint: disable=too-many-local
         )
     )
 
-    # buffer
-    good_args.append((default_encrypt, "buffer", False))
-    for recursive_flag in (" -b", " --buffer"):
-        good_args.append((default_encrypt + recursive_flag, "buffer", True))
+    # discovery
+    discovery_valid_configs = [
+        ["--discovery=1", "discovery", True],
+        ["--discovery=true", "discovery", True],
+        ["--discovery=0", "discovery", False],
+        ["--discovery=false", "discovery", False],
+    ]
+    for valid_config in discovery_valid_configs:
+        good_args.append(
+            (default_decrypt.replace(default_discovery, " " + valid_config[0]), "discovery", valid_config[2])
+        )
 
     return good_args
 
@@ -317,6 +322,8 @@ def test_parser_from_shell(argstring, attribute, value):
 @pytest.mark.parametrize("argstring, attribute, value", build_expected_good_args(from_file=True))
 def test_parser_fromfile(tmpdir, argstring, attribute, value):
     argfile = tmpdir.join("argfile")
+    if not "--discovery" in argstring:
+        argstring += " --discovery=true"
     argfile.write(argstring)
     parsed = arg_parsing.parse_args(["@{}".format(argfile)])
     assert getattr(parsed, attribute) == value
@@ -353,7 +360,6 @@ def build_bad_dummy_arguments():
     partial_patterns = {
         "-decrypt": "{arg} -i - -o - -S",
         "-encrypt": "{arg} -i - -o - -S",
-        "-decrypt-unsigned": "{arg} -i - -o - -S",
         "-input": "-d {arg} - -o - -S",
         "-output": "-d -i - {arg} - -S",
     }
@@ -456,194 +462,74 @@ def test_process_caching_config_required_parameters_missing(source):
 
 
 KEY_PROVIDER_CONFIGS = [
-    (  # single key, encrypt
-        [["provider=ex_provider", "key=ex_key"]],
-        "encrypt",
-        [{"provider": "ex_provider", "key": ["ex_key"], "discovery": False}],
-    ),
-    (  # multiple keys
+    ([["provider=ex_provider", "key=ex_key"]], "encrypt", [{"provider": "ex_provider", "key": ["ex_key"]}]),
+    (
         [["provider=ex_provider", "key=ex_key_1", "key=ex_key_2"]],
         "encrypt",
-        [{"provider": "ex_provider", "key": ["ex_key_1", "ex_key_2"], "discovery": False}],
+        [{"provider": "ex_provider", "key": ["ex_key_1", "ex_key_2"]}],
     ),
-    (  # unknown parameters
+    (
         [["provider=ex_provider", "key=ex_key_1", "key=ex_key_2", "a=b", "asdf=4"]],
         "encrypt",
-        [{"provider": "ex_provider", "key": ["ex_key_1", "ex_key_2"], "a": ["b"], "asdf": ["4"], "discovery": False}],
-    ),
-    (  # decrypt, with keys, no discovery
-        [["provider=ex_provider", "key=ex_key_1"]],
-        "decrypt",
-        [{"provider": "ex_provider", "key": ["ex_key_1"], "discovery": False}],
-    ),
-    (  # decrypt, aws-kms, with keys, no discovery
-        [["provider=aws-kms", "key=ex_key"]],
-        "decrypt",
-        [{"provider": "aws-kms", "key": ["ex_key"], "discovery": False}],
-    ),
-    (  # decrypt, explicit discovery true, no filter
-        [["provider=aws-kms", "discovery=true"]],
-        "decrypt",
-        [{"provider": "aws-kms", "key": [], "discovery": True}],
-    ),
-    (  # decrypt, explicit discovery false, no filter
-        [["provider=aws-kms", "discovery=false", "key=ex_key_1"]],
-        "decrypt",
-        [{"provider": "aws-kms", "key": ["ex_key_1"], "discovery": False}],
-    ),
-    (  # decrypt, explicit discovery, filter
-        [["provider=aws-kms", "discovery=true", "discovery-account=123", "discovery-partition=aws"]],
-        "decrypt",
-        [
-            {
-                "provider": "aws-kms",
-                "key": [],
-                "discovery": True,
-                "discovery-account": ["123"],
-                "discovery-partition": "aws",
-            }
-        ],
-    ),
-    (  # decrypt, explicit discovery, filter multiple accounts
-        [
-            [
-                "provider=aws-kms",
-                "discovery=true",
-                "discovery-account=123",
-                "discovery-account=456",
-                "discovery-partition=aws",
-            ]
-        ],
-        "decrypt",
-        [
-            {
-                "provider": "aws-kms",
-                "key": [],
-                "discovery": True,
-                "discovery-account": ["123", "456"],
-                "discovery-partition": "aws",
-            }
-        ],
-    ),
-    (None, "decrypt", [{"provider": identifiers.DEFAULT_MASTER_KEY_PROVIDER, "key": [], "discovery": True}]),
-    ([["provider=aws-kms", "key=ex_key"]], "decrypt", [{"provider": "aws-kms", "key": ["ex_key"], "discovery": False}]),
-    (
-        [["provider=" + identifiers.DEFAULT_MASTER_KEY_PROVIDER, "key=ex_key"]],
-        "decrypt",
-        [{"provider": identifiers.DEFAULT_MASTER_KEY_PROVIDER, "key": ["ex_key"], "discovery": False}],
-    ),
-    (
-        [["key=ex_key_1"]],
-        "encrypt",
-        [{"provider": identifiers.DEFAULT_MASTER_KEY_PROVIDER, "key": ["ex_key_1"], "discovery": False}],
-    ),
-    (  # decrypt-unsigned, with keys, no discovery
-        [["provider=ex_provider", "key=ex_key_1"]],
-        "decrypt-unsigned",
-        [{"provider": "ex_provider", "key": ["ex_key_1"], "discovery": False}],
-    ),
-    (  # decrypt-unsigned, explicit discovery true, no filter
-        [["provider=aws-kms", "discovery=true"]],
-        "decrypt-unsigned",
-        [{"provider": "aws-kms", "key": [], "discovery": True}],
-    ),
-    (  # decrypt-unsigned, explicit discovery false, no filter
-        [["provider=aws-kms", "discovery=false", "key=ex_key_1"]],
-        "decrypt-unsigned",
-        [{"provider": "aws-kms", "key": ["ex_key_1"], "discovery": False}],
-    ),
-    (  # decrypt-unsigned, explicit discovery, filter
-        [["provider=aws-kms", "discovery=true", "discovery-account=123", "discovery-partition=aws"]],
-        "decrypt-unsigned",
-        [
-            {
-                "provider": "aws-kms",
-                "key": [],
-                "discovery": True,
-                "discovery-account": ["123"],
-                "discovery-partition": "aws",
-            }
-        ],
-    ),
-    (  # decrypt-unsigned, explicit discovery, filter multiple accounts
-        [
-            [
-                "provider=aws-kms",
-                "discovery=true",
-                "discovery-account=123",
-                "discovery-account=456",
-                "discovery-partition=aws",
-            ]
-        ],
-        "decrypt-unsigned",
-        [
-            {
-                "provider": "aws-kms",
-                "key": [],
-                "discovery": True,
-                "discovery-account": ["123", "456"],
-                "discovery-partition": "aws",
-            }
-        ],
+        [{"provider": "ex_provider", "key": ["ex_key_1", "ex_key_2"], "a": ["b"], "asdf": ["4"]}],
     ),
 ]
+ALL_CONFIG = ([i[0][0] for i in KEY_PROVIDER_CONFIGS], "encrypt", [i[-1][0] for i in KEY_PROVIDER_CONFIGS])
+KEY_PROVIDER_CONFIGS.append(ALL_CONFIG)
+KEY_PROVIDER_CONFIGS.append((None, "decrypt", [{"provider": identifiers.DEFAULT_MASTER_KEY_PROVIDER, "key": []}]))
+KEY_PROVIDER_CONFIGS.append(([["provider=aws-kms"]], "decrypt", [{"provider": "aws-kms", "key": []}]))
+KEY_PROVIDER_CONFIGS.append(
+    (
+        [["provider=" + identifiers.DEFAULT_MASTER_KEY_PROVIDER]],
+        "decrypt",
+        [{"provider": identifiers.DEFAULT_MASTER_KEY_PROVIDER, "key": []}],
+    )
+)
+KEY_PROVIDER_CONFIGS.append(
+    ([["key=ex_key_1"]], "encrypt", [{"provider": identifiers.DEFAULT_MASTER_KEY_PROVIDER, "key": ["ex_key_1"]}])
+)
 
 
 @pytest.mark.parametrize("source, action, expected", KEY_PROVIDER_CONFIGS)
 def test_process_wrapping_key_provider_configs(source, action, expected):
-    test = arg_parsing._process_wrapping_key_provider_configs(source, action)
+    test = arg_parsing._process_wrapping_key_provider_configs(source, action, True)
 
     assert test == expected
 
 
 def test_process_wrapping_key_provider_configs_no_provider_on_encrypt():
     with pytest.raises(ParameterParseError) as excinfo:
-        arg_parsing._process_wrapping_key_provider_configs(None, "encrypt")
+        arg_parsing._process_wrapping_key_provider_configs(None, "encrypt", True)
 
-    excinfo.match(r"No wrapping key provider configuration found")
-
-
-@pytest.mark.parametrize("args", ["discovery=true", "discovery-account=123", "discovery-partition=aws"])
-def test_process_wrapping_key_provider_configs_multiple_discovery_partition(args):
-    with pytest.raises(ParameterParseError) as excinfo:
-        arg_parsing._process_wrapping_key_provider_configs([[args]], "encrypt")
-
-    excinfo.match(r"Discovery attributes are supported only during decryption")
-
-
-def test_process_wrapping_key_provider_configs_on_encrypt_with_discovery():
-    args = [["discovery=true", "discovery-account=123", "discovery-partition=aws", "discovery-partition=aws-gov"]]
-    with pytest.raises(ParameterParseError) as excinfo:
-        arg_parsing._process_wrapping_key_provider_configs(args, "decrypt")
-
-    excinfo.match(r"You can only specify discovery-partition once")
+    excinfo.match(r"No wrapping key provider configuration found.")
 
 
 def test_process_wrapping_key_provider_configs_not_exactly_one_provider():
     with pytest.raises(ParameterParseError) as excinfo:
         arg_parsing._process_wrapping_key_provider_configs(
-            [["provider=a", "provider=b", "key=ex_key_1", "key=ex_key_2"]], "encrypt"
+            [["provider=a", "provider=b", "key=ex_key_1", "key=ex_key_2"]], "encrypt", False
         )
 
     excinfo.match(r'Exactly one "provider" must be provided for each wrapping key provider configuration. 2 provided')
 
 
-@pytest.mark.parametrize("decrypt_mode", ("decrypt", "decrypt-unsigned"))
-@pytest.mark.parametrize("args", ["discovery=true", "discovery-account=123", "discovery-partition=aws"])
-def test_process_wrapping_key_provider_configs_discovery_with_nonkms_provider(args, decrypt_mode):
-    with pytest.raises(ParameterParseError) as excinfo:
-        arg_parsing._process_wrapping_key_provider_configs([["provider=notkms", args]], decrypt_mode)
+@pytest.mark.parametrize("provider", ("aws-kms", identifiers.DEFAULT_MASTER_KEY_PROVIDER))
+def test_wrapping_key_specified_on_decrypt_for_kms(provider):
+    source = [["provider=" + provider, "key=example"]]
 
-    excinfo.match(r"Discovery attributes are supported only for AWS KMS wrapping keys")
+    with pytest.raises(ParameterParseError) as excinfo:
+        arg_parsing._process_wrapping_key_provider_configs(source, "decrypt", True)
+
+    excinfo.match(r"Exact wrapping keys cannot be specified for aws-kms wrapping key provider on decrypt.")
 
 
 def test_process_wrapping_key_provider_configs_no_keys():
     source = [["provider=ex_provider", "aaa=sadfa"]]
 
     with pytest.raises(ParameterParseError) as excinfo:
-        arg_parsing._process_wrapping_key_provider_configs(source, "encrypt")
+        arg_parsing._process_wrapping_key_provider_configs(source, "encrypt", False)
 
-    excinfo.match(r"You must specify at least one key attribute and value in each --wrapping-keys parameter")
+    excinfo.match(r'At least one "key" must be provided for each wrapping key provider configuration')
 
 
 def test_parse_args(
@@ -652,11 +538,10 @@ def test_parse_args(
     patch_process_encryption_context,
     patch_process_caching_config,
 ):
-    mock_discovery_account = [[123]]
     mock_parsed_args = MagicMock(
         wrapping_keys=sentinel.raw_keys,
-        master_keys=None,
-        discovery_account=mock_discovery_account,
+        discovery=sentinel.discovery,
+        discovery_account=sentinel.discovery_account,
         discovery_partition=sentinel.discovery_partition,
         encryption_context=sentinel.raw_encryption_context,
         required_encryption_context_keys=None,
@@ -664,18 +549,18 @@ def test_parse_args(
         action=sentinel.action,
         version=False,
         dummy_redirect=None,
-        commitment_policy=sentinel.commitment_policy,
-        buffer=sentinel.buffer_output,
+        commitment_policy=CommitmentPolicy.REQUIRE_ENCRYPT_REQUIRE_DECRYPT,
     )
     patch_build_parser.return_value.parse_args.return_value = mock_parsed_args
     test = arg_parsing.parse_args(sentinel.raw_args)
 
     patch_build_parser.assert_called_once_with()
     patch_build_parser.return_value.parse_args.assert_called_once_with(args=sentinel.raw_args)
-
     patch_process_wrapping_key_provider_configs.assert_called_once_with(
         sentinel.raw_keys,
         sentinel.action,
+        sentinel.discovery,
+        {"account_ids": sentinel.discovery_account, "partition": sentinel.discovery_partition},
     )
     assert test.wrapping_keys is patch_process_wrapping_key_provider_configs.return_value
     patch_process_encryption_context.assert_called_once_with(
@@ -698,6 +583,7 @@ def test_parse_args_dummy_redirect(
 ):
     mock_parsed_args = MagicMock(
         wrapping_keys=sentinel.raw_keys,
+        discovery=True,
         encryption_context=sentinel.raw_encryption_context,
         caching=sentinel.raw_caching,
         action=sentinel.action,
@@ -738,69 +624,7 @@ def test_parse_args_error_raised_in_post_processing(
 
     arg_parsing.parse_args()
 
-    patch_build_parser.return_value.error.assert_called_once_with(
-        "You cannot specify both the --master-keys and --wrapping-keys parameters"
-    )
-
-
-def test_parse_args_missing_commitment_policy_wrapping_keys_parameter_fails(patch_build_parser):
-    mock_parsed_args = MagicMock(
-        wrapping_keys=sentinel.raw_keys,
-        master_keys=None,
-        commitment_policy=None,
-        dummy_redirect=None,
-        required_encryption_context_keys=None,
-    )
-    patch_build_parser.return_value.parse_args.return_value = mock_parsed_args
-
-    arg_parsing.parse_args(sentinel.raw_args)
-
-    patch_build_parser.return_value.error.assert_called_once_with(
-        "Commitment policy is required when specifying the --wrapping-keys parameter"
-    )
-
-
-def test_parse_args_bad_commitment_policy():
-    args = "-d -S -i - -o - --commitment-policy this-does-not-exist"
-
-    with pytest.raises(SystemExit) as excinfo:
-        arg_parsing.parse_args(shlex.split(args))
-
-    assert excinfo.value.args == (2,)
-
-
-def test_parse_args_missing_commitment_policy_master_keys_parameter_succeeds(patch_build_parser):
-    mock_parsed_args = MagicMock(
-        wrapping_keys=None,
-        master_keys=MagicMock(),
-        commitment_policy=None,
-        dummy_redirect=None,
-        required_encryption_context_keys=None,
-        caching=None,
-    )
-    patch_build_parser.return_value.parse_args.return_value = mock_parsed_args
-
-    arg_parsing.parse_args(sentinel.raw_args)
-
-    patch_build_parser.return_value.error.assert_not_called()
-
-
-def test_parse_args_with_commitment_policy_master_keys_parameter_succeeds(patch_build_parser):
-    mock_parsed_args = MagicMock(
-        wrapping_keys=None,
-        master_keys=MagicMock(),
-        commitment_policy=sentinel.commitment_policy,
-        dummy_redirect=None,
-        required_encryption_context_keys=None,
-        caching=None,
-    )
-    patch_build_parser.return_value.parse_args.return_value = mock_parsed_args
-
-    arg_parsing.parse_args(sentinel.raw_args)
-
-    patch_build_parser.return_value.error.assert_called_once_with(
-        "Commitment policy is only supported when using the --wrapping-keys parameter"
-    )
+    patch_build_parser.return_value.error.assert_called_once_with()
 
 
 @pytest.mark.parametrize(
@@ -808,16 +632,8 @@ def test_parse_args_with_commitment_policy_master_keys_parameter_succeeds(patch_
     (
         ("encrypt", None, None, {}, []),
         ("decrypt", None, None, {}, []),
-        ("decrypt-unsigned", None, None, {}, []),
         ("encrypt", ["encryption=context", "with=values"], None, {"encryption": "context", "with": "values"}, []),
         ("decrypt", ["encryption=context", "with=values"], None, {"encryption": "context", "with": "values"}, []),
-        (
-            "decrypt-unsigned",
-            ["encryption=context", "with=values"],
-            None,
-            {"encryption": "context", "with": "values"},
-            [],
-        ),
         (
             "encrypt",
             ["encryption=context", "with=values"],
@@ -839,20 +655,6 @@ def test_parse_args_with_commitment_policy_master_keys_parameter_succeeds(patch_
             {"encryption": "context", "with": "values"},
             ["key_1", "key_2", "key_3"],
         ),
-        (
-            "decrypt-unsigned",
-            ["encryption=context", "with=values"],
-            ["key_1", "key_2"],
-            {"encryption": "context", "with": "values"},
-            ["key_1", "key_2"],
-        ),
-        (
-            "decrypt-unsigned",
-            ["encryption=context", "with=values", "key_3"],
-            ["key_1", "key_2"],
-            {"encryption": "context", "with": "values"},
-            ["key_1", "key_2", "key_3"],
-        ),
     ),
 )
 def test_process_encryption_context(
@@ -878,17 +680,13 @@ def test_process_encryption_context_encrypt_required_key_fail():
 @pytest.mark.parametrize(
     "argstring",
     (
-        "--decrypt --input - -S --output - -w provider=ex_p_1 key=exkey discovery=1 discovery-account=123",
-        "--decrypt --input - -S --output - -w provider=ex_p_1 key=exkey discovery=1 discovery-partition=aws",
-        "--decrypt --input - -S --output - -w provider=ex_p_1 key=exkey discovery=0 discovery-account=123",
-        "--decrypt --input - -S --output - -w provider=ex_p_1 key=exkey discovery=0 discovery-partition=aws",
-        "--decrypt --input - -S --output - -w provider=ex_pr_1 key=exkey discovery=0 discovery-partition=aws"
-        " discovery-account=123",
-        "--decrypt-unsigned --input - -S --output - -w provider=ex_p_1 key=exkey discovery=1 discovery-account=123",
-        "--decrypt-unsigned --input - -S --output - -w provider=ex_p_1 key=exkey discovery=1 discovery-partition=aws",
-        "--decrypt-unsigned --input - -S --output - -w provider=ex_p_1 key=exkey discovery=0 discovery-account=123",
-        "--decrypt-unsigned --input - -S --output - -w provider=ex_p_1 key=exkey discovery=0 discovery-partition=aws",
-        "--decrypt-unsigned --input - -S --output - -w provider=ex_pr_1 key=exkey discovery=0 discovery-partition=aws",
+        "--decrypt --input - -S --output - -w provider=ex_p_1 key=exkey",  # V2 requires discovery
+        "--decrypt --input - -S --output - -w provider=ex_p_1 key=exkey --discovery=1 --discovery-account=123",
+        "--decrypt --input - -S --output - -w provider=ex_p_1 key=exkey --discovery=1 --discovery-partition=aws",
+        "--decrypt --input - -S --output - -w provider=ex_p_1 key=exkey --discovery=0 --discovery-account=123",
+        "--decrypt --input - -S --output - -w provider=ex_p_1 key=exkey --discovery=0 --discovery-partition=aws",
+        "--decrypt --input - -S --output - -w provider=ex_pr_1 key=exkey --discovery=0 --discovery-partition=aws"
+        " --discovery-account=123",
     ),
 )
 def test_invalid_discovery(argstring):
@@ -905,86 +703,4 @@ def test_discovery_bool():
     assert arg_parsing.discovery_pseudobool("false") is False
     assert arg_parsing.discovery_pseudobool("0") is False
     assert arg_parsing.discovery_pseudobool(False) is False
-
-    with pytest.raises(ParameterParseError) as excinfo:
-        arg_parsing.discovery_pseudobool(None)
-    excinfo.match("Value .* could not be parsed as true or false")
-
-
-@pytest.mark.parametrize(
-    "parsed_args",
-    [
-        {"discovery-account": ["123"]},
-        {"discovery-partition": "aws"},
-        {"discovery-account": ["123"], "discovery-partition": "aws"},
-        {"discovery": "false", "discovery-account": ["123"]},
-        {"discovery": "false", "discovery-partition": "aws"},
-        {"discovery": "false", "discovery-account": ["123"], "discovery-partition": "aws"},
-        {"discovery": "true", "discovery-account": ["123"]},
-        {"discovery": "true", "discovery-partition": "aws"},
-    ],
-)
-def test_process_discovery_args_invalid(parsed_args):
-    with pytest.raises(ParameterParseError):
-        arg_parsing._process_discovery_args(parsed_args)
-
-
-def test_process_discovery_args_no_discovery_encrypt():
-    parsed_args = {"provider": "aws-kms"}
-    arg_parsing._process_discovery_args(parsed_args)
-    assert not parsed_args["discovery"]
-
-
-def test_process_discovery_args_discovery_true_no_filter():
-    parsed_args = {"provider": "aws-kms", "discovery": "true"}
-    arg_parsing._process_discovery_args(parsed_args)
-    assert parsed_args["discovery"]
-
-
-def test_process_discovery_args_discovery_true_with_filter():
-    parsed_args = {
-        "provider": "aws-kms",
-        "discovery": "true",
-        "discovery-account": ["123"],
-        "discovery-partition": ["aws"],
-    }
-    arg_parsing._process_discovery_args(parsed_args)
-    assert parsed_args["discovery"]
-    assert parsed_args["discovery-account"] == ["123"]
-    assert parsed_args["discovery-partition"] == "aws"
-
-
-def test_process_discovery_args_discovery_empty_accounts_list():
-    parsed_args = {
-        "provider": "aws-kms",
-        "discovery": "true",
-        "discovery-account": [],
-        "discovery-partition": ["aws"],
-    }
-    with pytest.raises(ParameterParseError) as excinfo:
-        arg_parsing._process_discovery_args(parsed_args)
-    excinfo.match(r"When specifying discovery-partition, you must also specify discovery-account")
-
-
-def test_process_discovery_args_discovery_empty_account():
-    parsed_args = {
-        "provider": "aws-kms",
-        "discovery": "true",
-        "discovery-account": ["123", ""],
-        "discovery-partition": ["aws"],
-    }
-    with pytest.raises(ParameterParseError) as excinfo:
-        arg_parsing._process_discovery_args(parsed_args)
-    excinfo.match(r"Value passed to discovery-account cannot be empty")
-
-
-def test_process_discovery_args_discovery_empty_partition():
-    parsed_args = {
-        "provider": "aws-kms",
-        "discovery": "true",
-        "discovery-account": ["123"],
-        "discovery-partition": [""],
-    }
-    with pytest.raises(ParameterParseError) as excinfo:
-        arg_parsing._process_discovery_args(parsed_args)
-    excinfo.match(r"Value passed to discovery-partition cannot be empty")
+    assert arg_parsing.discovery_pseudobool(None) is None
