@@ -251,7 +251,7 @@ def test_process_cli_request_source_dir_nonrecursive(tmpdir, patch_iohandler):
     destination = tmpdir.mkdir("destination")
     metadata_writer = MetadataWriter(True)()
     aws_encryption_sdk_cli.process_cli_request(
-        stream_args={},
+        stream_args=sentinel.stream_args,
         parsed_args=MagicMock(
             input=str(source),
             output=str(destination),
@@ -263,9 +263,7 @@ def test_process_cli_request_source_dir_nonrecursive(tmpdir, patch_iohandler):
             encode=sentinel.encode_output,
             encryption_context=sentinel.encryption_context,
             required_encryption_context_keys=sentinel.required_keys,
-            commitment_policy=CommitmentPolicyArgs.FORBID_ENCRYPT_ALLOW_DECRYPT,
-            buffer=sentinel.buffer_output,
-            max_encrypted_data_keys=None,
+            commitment_policy=CommitmentPolicyArgs.require_encrypt_require_decrypt,
         ),
     )
 
@@ -277,9 +275,7 @@ def test_process_cli_request_source_dir_nonrecursive(tmpdir, patch_iohandler):
         encode_output=sentinel.encode_output,
         required_encryption_context=sentinel.encryption_context,
         required_encryption_context_keys=sentinel.required_keys,
-        commitment_policy=CommitmentPolicy.FORBID_ENCRYPT_ALLOW_DECRYPT,
-        buffer_output=sentinel.buffer_output,
-        max_encrypted_data_keys=None,
+        commitment_policy=CommitmentPolicy.REQUIRE_ENCRYPT_REQUIRE_DECRYPT,
     )
     assert not patch_iohandler.return_value.process_single_operation.called
     assert not patch_iohandler.return_value.process_dir.called
@@ -291,7 +287,7 @@ def test_process_cli_request_no_commitment_policy(tmpdir, patch_iohandler):
     destination = tmpdir.mkdir("destination")
     metadata_writer = MetadataWriter(True)()
     aws_encryption_sdk_cli.process_cli_request(
-        stream_args={},
+        stream_args=sentinel.stream_args,
         parsed_args=MagicMock(
             input=str(source),
             output=str(destination),
@@ -304,8 +300,6 @@ def test_process_cli_request_no_commitment_policy(tmpdir, patch_iohandler):
             encryption_context=sentinel.encryption_context,
             required_encryption_context_keys=sentinel.required_keys,
             commitment_policy=None,
-            buffer=sentinel.buffer_output,
-            max_encrypted_data_keys=None,
         ),
     )
 
@@ -317,9 +311,7 @@ def test_process_cli_request_no_commitment_policy(tmpdir, patch_iohandler):
         encode_output=sentinel.encode_output,
         required_encryption_context=sentinel.encryption_context,
         required_encryption_context_keys=sentinel.required_keys,
-        commitment_policy=CommitmentPolicy.FORBID_ENCRYPT_ALLOW_DECRYPT,
-        buffer_output=sentinel.buffer_output,
-        max_encrypted_data_keys=None,
+        commitment_policy=CommitmentPolicy.REQUIRE_ENCRYPT_REQUIRE_DECRYPT,
     )
     assert not patch_iohandler.return_value.process_single_operation.called
     assert not patch_iohandler.return_value.process_dir.called
@@ -342,9 +334,7 @@ def test_process_cli_request_source_dir_destination_nondir(tmpdir):
                 metadata_output=MetadataWriter(True)(),
                 encryption_context={},
                 required_encryption_context_keys=[],
-                commitment_policy=CommitmentPolicyArgs.FORBID_ENCRYPT_ALLOW_DECRYPT,
-                buffer=False,
-                max_encrypted_data_keys=None,
+                commitment_policy=CommitmentPolicyArgs.require_encrypt_require_decrypt,
             ),
         )
     excinfo.match(r"If operating on a source directory, destination must be an existing directory")
@@ -354,7 +344,7 @@ def test_process_cli_request_source_dir_destination_dir(tmpdir, patch_iohandler)
     source = tmpdir.mkdir("source_dir")
     destination = tmpdir.mkdir("destination_dir")
     aws_encryption_sdk_cli.process_cli_request(
-        stream_args={},
+        stream_args=sentinel.stream_args,
         parsed_args=MagicMock(
             input=str(source),
             output=str(destination),
@@ -365,13 +355,12 @@ def test_process_cli_request_source_dir_destination_dir(tmpdir, patch_iohandler)
             decode=sentinel.decode_input,
             encode=sentinel.encode_output,
             metadata_output=MetadataWriter(True)(),
-            commitment_policy=CommitmentPolicyArgs.FORBID_ENCRYPT_ALLOW_DECRYPT,
-            buffer=sentinel.buffer_output,
+            commitment_policy=CommitmentPolicyArgs.require_encrypt_require_decrypt,
         ),
     )
 
     patch_iohandler.return_value.process_dir.assert_called_once_with(
-        stream_args={}, source=str(source), destination=str(destination), suffix=sentinel.suffix
+        stream_args=sentinel.stream_args, source=str(source), destination=str(destination), suffix=sentinel.suffix
     )
     assert not patch_iohandler.return_value.process_single_file.called
     assert not patch_iohandler.return_value.process_single_operation.called
@@ -399,14 +388,13 @@ def test_process_cli_request_source_stdin(tmpdir, patch_iohandler):
         decode=sentinel.decode_input,
         encode=sentinel.encode_output,
         metadata_output=MetadataWriter(True)(),
-        commitment_policy=CommitmentPolicyArgs.FORBID_ENCRYPT_ALLOW_DECRYPT,
-        buffer=sentinel.buffer_output,
+        commitment_policy=CommitmentPolicyArgs.require_encrypt_require_decrypt,
     )
-    aws_encryption_sdk_cli.process_cli_request(stream_args={}, parsed_args=mock_parsed_args)
+    aws_encryption_sdk_cli.process_cli_request(stream_args=sentinel.stream_args, parsed_args=mock_parsed_args)
     assert not patch_iohandler.return_value.process_dir.called
     assert not patch_iohandler.return_value.process_single_file.called
     patch_iohandler.return_value.process_single_operation.assert_called_once_with(
-        stream_args={}, source="-", destination=str(destination)
+        stream_args=sentinel.stream_args, source="-", destination=str(destination)
     )
 
 
@@ -426,8 +414,7 @@ def test_process_cli_request_source_file_destination_dir(tmpdir, patch_iohandler
             decode=sentinel.decode_input,
             encode=sentinel.encode_output,
             metadata_output=MetadataWriter(True)(),
-            commitment_policy=CommitmentPolicyArgs.FORBID_ENCRYPT_ALLOW_DECRYPT,
-            buffer=sentinel.buffer_output,
+            commitment_policy=CommitmentPolicyArgs.require_encrypt_require_decrypt,
         ),
     )
     assert not patch_iohandler.return_value.process_dir.called
@@ -455,8 +442,7 @@ def test_process_cli_request_source_file_destination_file(tmpdir, patch_iohandle
             decode=sentinel.decode_input,
             encode=sentinel.encode_output,
             metadata_output=MetadataWriter(True)(),
-            commitment_policy=CommitmentPolicyArgs.FORBID_ENCRYPT_ALLOW_DECRYPT,
-            buffer=sentinel.buffer_output,
+            commitment_policy=CommitmentPolicyArgs.require_encrypt_require_decrypt,
         ),
     )
     assert not patch_iohandler.return_value.process_dir.called
@@ -482,9 +468,7 @@ def test_process_cli_request_invalid_source(tmpdir):
                 metadata_output=MetadataWriter(True)(),
                 encryption_context={},
                 required_encryption_context_keys=[],
-                commitment_policy=CommitmentPolicyArgs.FORBID_ENCRYPT_ALLOW_DECRYPT,
-                buffer=False,
-                max_encrypted_data_keys=None,
+                commitment_policy=CommitmentPolicyArgs.require_encrypt_require_decrypt,
             ),
         )
     excinfo.match(r"Invalid source.  Must be a valid pathname pattern or stdin \(-\)")
@@ -504,7 +488,7 @@ def test_process_cli_request_globbed_source_non_directory_target(tmpdir, patch_i
         aws_encryption_sdk_cli.process_cli_request(
             stream_args={"mode": "encrypt"},
             parsed_args=MagicMock(
-                commitment_policy=CommitmentPolicyArgs.FORBID_ENCRYPT_ALLOW_DECRYPT,
+                commitment_policy=CommitmentPolicyArgs.require_encrypt_require_decrypt,
                 input=source,
                 output=str(target_file),
                 recursive=False,
@@ -539,8 +523,7 @@ def test_process_cli_request_source_contains_directory_nonrecursive(tmpdir, patc
             encode=False,
             decode=False,
             metadata_output=MetadataWriter(True)(),
-            commitment_policy=CommitmentPolicyArgs.FORBID_ENCRYPT_ALLOW_DECRYPT,
-            buffer=False,
+            commitment_policy=CommitmentPolicyArgs.require_encrypt_require_decrypt,
         ),
     )
 
@@ -559,12 +542,7 @@ def test_process_cli_request_source_contains_directory_nonrecursive(tmpdir, patc
     (
         (
             MagicMock(
-                action=sentinel.mode,
-                encryption_context=None,
-                algorithm=None,
-                frame_length=None,
-                max_length=None,
-                max_encrypted_data_keys=None,
+                action=sentinel.mode, encryption_context=None, algorithm=None, frame_length=None, max_length=None
             ),
             {"materials_manager": sentinel.materials_manager, "mode": sentinel.mode},
         ),
@@ -575,7 +553,6 @@ def test_process_cli_request_source_contains_directory_nonrecursive(tmpdir, patc
                 algorithm=None,
                 frame_length=None,
                 max_length=sentinel.max_length,
-                max_encrypted_data_keys=None,
             ),
             {
                 "materials_manager": sentinel.materials_manager,
@@ -585,23 +562,7 @@ def test_process_cli_request_source_contains_directory_nonrecursive(tmpdir, patc
         ),
         (
             MagicMock(
-                action=sentinel.mode,
-                encryption_context=None,
-                algorithm=None,
-                frame_length=None,
-                max_length=None,
-                max_encrypted_data_keys=sentinel.max_encrypted_data_keys,
-            ),
-            {"materials_manager": sentinel.materials_manager, "mode": sentinel.mode},
-        ),
-        (
-            MagicMock(
-                action=sentinel.mode,
-                encryption_context=None,
-                algorithm=None,
-                frame_length=None,
-                max_length=None,
-                max_encrypted_data_keys=None,
+                action=sentinel.mode, encryption_context=None, algorithm=None, frame_length=None, max_length=None
             ),
             {"materials_manager": sentinel.materials_manager, "mode": sentinel.mode},
         ),
@@ -612,7 +573,6 @@ def test_process_cli_request_source_contains_directory_nonrecursive(tmpdir, patc
                 algorithm="AES_256_GCM_IV12_TAG16_HKDF_SHA384_ECDSA_P384",
                 frame_length=sentinel.frame_length,
                 max_length=None,
-                max_encrypted_data_keys=None,
             ),
             {"materials_manager": sentinel.materials_manager, "mode": sentinel.mode},
         ),
@@ -623,7 +583,6 @@ def test_process_cli_request_source_contains_directory_nonrecursive(tmpdir, patc
                 algorithm="AES_256_GCM_IV12_TAG16_HKDF_SHA384_ECDSA_P384",
                 frame_length=sentinel.frame_length,
                 max_length=None,
-                max_encrypted_data_keys=None,
             ),
             {
                 "materials_manager": sentinel.materials_manager,
@@ -640,7 +599,6 @@ def test_process_cli_request_source_contains_directory_nonrecursive(tmpdir, patc
                 algorithm="AES_256_GCM_IV12_TAG16_HKDF_SHA384_ECDSA_P384",
                 frame_length=sentinel.frame_length,
                 max_length=None,
-                max_encrypted_data_keys=None,
             ),
             {
                 "materials_manager": sentinel.materials_manager,
@@ -657,7 +615,6 @@ def test_process_cli_request_source_contains_directory_nonrecursive(tmpdir, patc
                 algorithm=None,
                 frame_length=sentinel.frame_length,
                 max_length=None,
-                max_encrypted_data_keys=None,
             ),
             {
                 "materials_manager": sentinel.materials_manager,
@@ -673,7 +630,6 @@ def test_process_cli_request_source_contains_directory_nonrecursive(tmpdir, patc
                 algorithm="AES_256_GCM_IV12_TAG16_HKDF_SHA384_ECDSA_P384",
                 frame_length=None,
                 max_length=None,
-                max_encrypted_data_keys=None,
             ),
             {
                 "materials_manager": sentinel.materials_manager,
@@ -695,7 +651,6 @@ def patch_for_cli(mocker):
         version=False,
         verbosity=sentinel.verbosity,
         quiet=sentinel.quiet,
-        master_keys=sentinel.master_keys,
         wrapping_keys=sentinel.wrapping_keys,
         caching=sentinel.caching_config,
         input=sentinel.input,
@@ -709,8 +664,6 @@ def patch_for_cli(mocker):
         discovery_partition=sentinel.discovery_partition,
         decode=sentinel.decode_input,
         encode=sentinel.encode_output,
-        commitment_policy=CommitmentPolicyArgs.FORBID_ENCRYPT_ALLOW_DECRYPT,
-        buffer=sentinel.buffer_output,
     )
     mocker.patch.object(aws_encryption_sdk_cli, "setup_logger")
     mocker.patch.object(aws_encryption_sdk_cli, "build_crypto_materials_manager_from_args")
@@ -773,7 +726,15 @@ def test_cli_unknown_error_capture_stacktrace(patch_process_cli_request, tmpdir,
     patch_process_cli_request.side_effect = Exception(message)
 
     test = aws_encryption_sdk_cli.cli(
-        shlex.split("-Sd -i " + str(plaintext) + " -o " + str(tmpdir.join("ciphertext")) + " " + requested_log_level)
+        shlex.split(
+            "-Sd -i "
+            + str(plaintext)
+            + " -o "
+            + str(tmpdir.join("ciphertext"))
+            + " "
+            + requested_log_level
+            + " --discovery=true"
+        )
     )
 
     all_logs = log_stream.getvalue()
